﻿using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;

using TestLibrary;

namespace TestModule1.ViewModels
{
    /// <summary>
    /// 메시지 뷰 모델
    /// </summary>
    public class MessageViewModel : BindableBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 이벤트 수집기
        /// </summary>
        private IEventAggregator eventAggregator;

        /// <summary>
        /// 메시지
        /// </summary>
        private string message = "Message to Send";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 메시지 - Message

        /// <summary>
        /// 메시지
        /// </summary>
        public string Message
        {
            get
            {
                return this.message;
            }
            set
            {
                SetProperty(ref this.message, value);
            }
        }

        #endregion
        #region 메시지 송신 명령 - SendMessageCommand

        /// <summary>
        /// 메시지 송신 명령
        /// </summary>
        public DelegateCommand SendMessageCommand { get; private set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MessageViewModel(eventAggregator)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="eventAggregator">이벤트 수집기</param>
        public MessageViewModel(IEventAggregator eventAggregator)
        {
            this.eventAggregator = eventAggregator;

            SendMessageCommand = new DelegateCommand(SendMessage);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 메시지 송신하기 - SendMessage()

        /// <summary>
        /// 메시지 송신하기
        /// </summary>
        private void SendMessage()
        {
            this.eventAggregator.GetEvent<MessageSentEvent>().Publish(Message);
        }

        #endregion
    }
}